==> news_1.0.jar: edu/northwestern/news/anomaly/Sampler.java <==
/**
 * NEWS Project
 *
 * File:         Sampler.java
 * RCS:          $Id: Sampler.java,v 1.3 2008/05/19 01:29:00 drc915 Exp $
 * Description:  Sampler class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 7, 2008 at 10:31:51 AM
 * Language:     Java
 * Package:      edu.northwestern.news.anomaly
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2008, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.news.anomaly;

import edu.northwestern.news.util.PluginInterface;

/**
 * @author David Choffnes &lt;drchoffnes@cs.northwestern.edu&gt;
 *
 * The Sampler class actually does sampling.
 */
public abstract class Sampler {
	protected MovingAverage myAverage;
	protected String name;
	protected PluginInterface pi;
	
	public Sampler(MovingAverage ma, String name, PluginInterface pi){
		this.name = name;
		this.myAverage = ma;
		this.pi = pi;
	}
	
	public abstract void sample();

	public void setMovingAverage(MovingAverage movingAverage) {
		myAverage = movingAverage;
		
	}
}

==> news_2.0.1.jar: edu/northwestern/news/anomaly/Sampler.java <==
/**
 * NEWS Project
 *
 * File:         Sampler.java
 * RCS:          $Id: Sampler.java,v 1.4 2009/10/19 14:36:14 drc915 Exp $
 * Description:  Sampler class (see below)
 * Author:       David Choffnes
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 7, 2008 at 10:31:51 AM
 * Language:     Java
 * Package:      edu.northwestern.news.anomaly
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2008, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.news.anomaly;

import java.util.ArrayList;

import edu.northwestern.news.util.PluginInterface;

/**
 * @author David Choffnes &lt;drchoffnes@cs.northwestern.edu&gt;
 *
 * The Sampler class actually does sampling.
 */
public abstract class Sampler {
	protected ArrayList<MovingAverage> myAverage;
	protected String name;
	protected PluginInterface pi;
	
	public Sampler(ArrayList<MovingAverage> ma, String name, PluginInterface pi){
		this.name = name;
		this.myAverage = ma;
		this.pi = pi;
	}
	
	public abstract void sample();

	public void setMovingAverage(ArrayList<MovingAverage> movingAverage) {
		myAverage = movingAverage;
		
	}
}
